`houseprices` <-
structure(list(area = c(694, 905, 802, 1366, 716, 963, 821, 714, 
1018, 887, 790, 696, 771, 1006, 1191), bedrooms = c(4, 4, 4, 
4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 6), sale.price = c(192, 215, 
215, 274, 112.7, 185, 212, 220, 276, 260, 221.5, 255, 260, 293, 
375)), .Names = c("area", "bedrooms", "sale.price"), row.names = c("9", 
"10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", 
"21", "22", "23"), class = "data.frame")
